@@ -1,10 +1,10 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::PromptIfStale; # git description: v0.036-2-g7ed0deb
+package Dist::Zilla::Plugin::PromptIfStale; # git description: v0.037-2-g26d2b30
 # ABSTRACT: Check at build/release time if modules are out of date
 # KEYWORDS: prerequisites upstream dependencies modules metadata update stale
 # vim: set ts=8 sw=4 tw=78 et :
-$Dist::Zilla::Plugin::PromptIfStale::VERSION = '0.037';
+our $VERSION = '0.038';
 use Moose;
 with 'Dist::Zilla::Role::BeforeBuild',
     'Dist::Zilla::Role::AfterBuild',
@@ -447,7 +447,7 @@ Dist::Zilla::Plugin::PromptIfStale - Check at build/release time if modules are
 
 =head1 VERSION
 
-version 0.037
+version 0.038
 
 =head1 SYNOPSIS
 
